==> haskell-cassava-megaparsec-2.1.1-145.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-cassava-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cassava-megaparsec
version:              2.1.1
visibility:           public
id:                   cassava-megaparsec-2.1.1-KFsFdMCo9qy4e7uTwKHk6Y
key:                  cassava-megaparsec-2.1.1-KFsFdMCo9qy4e7uTwKHk6Y
license:              MIT
maintainer:           Mark Karpov <markkarpov92@gmail.org>
author:               Mark Karpov <markkarpov92@gmail.org>
homepage:             https://github.com/stackbuilders/cassava-megaparsec
synopsis:
    Megaparsec parser of CSV files that plays nicely with Cassava

description:
    Megaparsec parser of CSV files that plays nicely with Cassava.

category:             Text, Web, CSV, Parsing
abi:                  e294ee20248c9938205e268ce0988a0b
exposed:              True
exposed-modules:
    Data.Csv.Parser.Megaparsec Data.Csv.Parser.Megaparsec.Internals

import-dirs:          /usr/lib/ghc-9.6.6/site-local/cassava-megaparsec-2.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/cassava-megaparsec-2.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/cassava-megaparsec-2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cassava-megaparsec
hs-libraries:         HScassava-megaparsec-2.1.1-KFsFdMCo9qy4e7uTwKHk6Y
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    cassava-0.5.4.1-I5H7lXHpRMwDMqqRDQwXhI
    megaparsec-9.7.0-Fzm61TdpQu7Cpey7aoa8J9
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:
    /usr/share/doc/haskell-cassava-megaparsec/html/cassava-megaparsec.haddock

haddock-html:         /usr/share/doc/haskell-cassava-megaparsec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cassava-megaparsec-2.1.1-146-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-cassava-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cassava-megaparsec
version:              2.1.1
visibility:           public
id:                   cassava-megaparsec-2.1.1-5CuOjdpmkte4mDtMCW1icg
key:                  cassava-megaparsec-2.1.1-5CuOjdpmkte4mDtMCW1icg
license:              MIT
maintainer:           Mark Karpov <markkarpov92@gmail.org>
author:               Mark Karpov <markkarpov92@gmail.org>
homepage:             https://github.com/stackbuilders/cassava-megaparsec
synopsis:
    Megaparsec parser of CSV files that plays nicely with Cassava

description:
    Megaparsec parser of CSV files that plays nicely with Cassava.

category:             Text, Web, CSV, Parsing
abi:                  129d5072d6be97a5f02cdbba7391ac92
exposed:              True
exposed-modules:
    Data.Csv.Parser.Megaparsec Data.Csv.Parser.Megaparsec.Internals

import-dirs:          /usr/lib/ghc-9.6.6/site-local/cassava-megaparsec-2.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/cassava-megaparsec-2.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/cassava-megaparsec-2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cassava-megaparsec
hs-libraries:         HScassava-megaparsec-2.1.1-5CuOjdpmkte4mDtMCW1icg
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    cassava-0.5.4.1-1CM8h0noLla7Uv16d8t4LK
    megaparsec-9.7.0-CJUMznUvVaqA9LkZfHNyDE
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-cassava-megaparsec/html/cassava-megaparsec.haddock

haddock-html:         /usr/share/doc/haskell-cassava-megaparsec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
